@@ -13,6 +13,7 @@ from dkist_processing_math.transform import scale_matrix
 from dkist_processing_math.transform import shear_matrix
 from dkist_processing_math.transform import translate_arrays
 from dkist_processing_math.transform import translation_matrix
+from dkist_processing_math.transform.binning import resize_arrays
 
 
 @pytest.fixture()
@@ -61,6 +62,19 @@ def binned_array(numpy_array, binned_arrays):
     return binned_arrays[0]
 
 
+@pytest.fixture()
+def resized_arrays(numpy_arrays):
+    temp_arrays = np.zeros((2, 20, 100), dtype=numpy_arrays[0].dtype)
+    for array, temp_array in zip(numpy_arrays, temp_arrays):
+        temp_array[:, :] = transform.resize_local_mean(array, (20, 100), preserve_range=True)
+    return temp_arrays
+
+
+@pytest.fixture()
+def resized_array(resized_arrays):
+    return resized_arrays[0]
+
+
 def test_bin_arrays(numpy_arrays, binned_arrays):
     """
     Given: an iterable of numpy_arrays
@@ -92,6 +106,27 @@ def test_bin_arrays_bad_bin_factor(numpy_array):
         next(bin_arrays(numpy_array, (3, 3)))
 
 
+def test_resize_arrays(numpy_arrays, resized_arrays):
+    """
+    Given: an iterable of numpy_arrays
+    When: resizing an iterable of numpy_arrays
+    Then: an Iterator of resized versions of the input arrays is returned
+    """
+    results = resize_arrays(numpy_arrays, (20, 100))
+    for result, resized_array in zip(results, resized_arrays):
+        np.testing.assert_allclose(result, resized_array)
+
+
+def test_resize_arrays_single_array(numpy_array, resized_array):
+    """
+    Given: a single numpy array
+    When: resizing that array
+    Then: an Iterator of resized versions of the input arrays is returned
+    """
+    result = next(resize_arrays(numpy_array, (20, 100)))
+    np.testing.assert_allclose(result, resized_array)
+
+
 def test_affine_transform_specify_matrix(numpy_array):
     """
     Given: a numpy_array
